@@ -1,6 +1,6 @@
 import pandas as pd
 import streamlit as st
-from pandas_profiling import ProfileReport
+from ydata_profiling import ProfileReport
 from streamlit_ydata_profiling import st_profile_report
 
 # Title
